@@ -27,6 +27,7 @@ from prometheus_client import \
     push_to_gateway, write_to_textfile, start_http_server, exposition
 import redis
 from redis import asyncio as aioredis
+from clickhouse_pool import ChPool
 
 
 @singleton
@@ -158,6 +159,7 @@ services = {
     "aiokafka_consumer": {},
 
     "clickhouse_client": {},
+    "clickhouse_pool": {},
     "aio_clickhouse": {},
 
     "azure_container_client": {},
@@ -274,24 +276,13 @@ class Factory:
 
         return self.get_instance(service_builder, service_name, instance_name, [], kwargs)
 
-    def clickhouse_client(self, **kwargs) -> ch_d.Client:
-        r"""Create and return object of clickhouse client
-            :Keyword Arguments:
-                * *type* (``str``) -- postfix for secret and config name (clickhouse_TYPE). Default: None (clickhouse)
-            """
-        service_name = "clickhouse_client"
-        instance_name = self.def_instance_name if not self.key_istance_name in kwargs else kwargs[self.key_istance_name]
 
+    def _get_clickhouse_kwargs(self, kwargs):
         ch_type = None if not "type" in kwargs else kwargs["type"]
         secrets = self._get_clickhouse_secrets(ch_type)
         config = self._get_clickhouse_config(ch_type)
-
         if "type" in kwargs.keys():
             del kwargs["type"]
-
-        args = []
-        #args.append(config["url"] if "url" not in kwargs else kwargs["url"])
-
         kwargs["host"] = config["url"] if not ("host" in kwargs) else kwargs["host"]
         kwargs["host"] = kwargs["host"] if not ("url" in kwargs) else kwargs["url"]
         kwargs["port"] = config["port"] if not ("port" in kwargs) else kwargs["port"]
@@ -299,7 +290,27 @@ class Factory:
         kwargs["password"] = secrets["password"] if not ("password" in kwargs) else kwargs["password"]
         kwargs["secure"] = True if "secure" not in kwargs else kwargs["secure"]
         kwargs["verify"] = False if "verify" not in kwargs else kwargs["verify"]
+        return kwargs
 
+
+    def clickhouse_pool(self, **kwargs) -> ChPool:
+        service_name = "clickhouse_pool"
+        instance_name = self.def_instance_name if not self.key_istance_name in kwargs else kwargs[self.key_istance_name]
+        kwargs = self._get_clickhouse_kwargs(kwargs)
+        args = []
+        return self.get_instance(ChPool, service_name, instance_name, args, kwargs)
+
+
+
+    def clickhouse_client(self, **kwargs) -> ch_d.Client:
+        r"""Create and return object of clickhouse client
+            :Keyword Arguments:
+                * *type* (``str``) -- postfix for secret and config name (clickhouse_TYPE). Default: None (clickhouse)
+            """
+        service_name = "clickhouse_client"
+        instance_name = self.def_instance_name if not self.key_istance_name in kwargs else kwargs[self.key_istance_name]
+        kwargs = self._get_clickhouse_kwargs(kwargs)
+        args = []
         return self.get_instance(ch_d.Client, service_name, instance_name, args, kwargs)
 
     def aio_clickhouse(self, loop: AbstractEventLoop, **kwargs) -> ClickhouseAioClient:
